searchData={"items":[{"type":"module","title":"Kday","doc":"Functions to return the date of the first, last or nth day of the week\non, nearest, before or after a given date.","ref":"Kday.html"},{"type":"function","title":"Kday.first_kday/2","doc":"Return the date of the first `day_of_week` on or after the\nspecified `date`.","ref":"Kday.html#first_kday/2"},{"type":"function","title":"Arguments - Kday.first_kday/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#first_kday/2-arguments"},{"type":"function","title":"Returns - Kday.first_kday/2","doc":"* A `%Date{”}` in the calendar of the date provided as an argument","ref":"Kday.html#first_kday/2-returns"},{"type":"function","title":"Examples - Kday.first_kday/2","doc":"# US election day\n    iex> Kday.first_kday(~D[2017-11-02], 2)\n    ~D[2017-11-07]\n\n    # US Daylight savings end\n    iex> Kday.first_kday(~D[2017-11-01], 7)\n    ~D[2017-11-05]","ref":"Kday.html#first_kday/2-examples"},{"type":"function","title":"Kday.gregorian_days_to_day_of_week/1","doc":"Returns the day of the week for a given\n`gregorian_day_number`.","ref":"Kday.html#gregorian_days_to_day_of_week/1"},{"type":"function","title":"Arguments - Kday.gregorian_days_to_day_of_week/1","doc":"* `gregorian_day_number` is the number of days since the start\n  of the epoch.","ref":"Kday.html#gregorian_days_to_day_of_week/1-arguments"},{"type":"function","title":"Returns - Kday.gregorian_days_to_day_of_week/1","doc":"* An integer representing a day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#gregorian_days_to_day_of_week/1-returns"},{"type":"function","title":"Examples - Kday.gregorian_days_to_day_of_week/1","doc":"iex> days = Date.to_gregorian_days ~D[2019-01-01]\n    iex> Kday.gregorian_days_to_day_of_week(days) == 2\n    true","ref":"Kday.html#gregorian_days_to_day_of_week/1-examples"},{"type":"function","title":"Kday.kday_after/2","doc":"Return the date of the `day_of_week` after the\nspecified `date`.","ref":"Kday.html#kday_after/2"},{"type":"function","title":"Arguments - Kday.kday_after/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#kday_after/2-arguments"},{"type":"function","title":"Returns - Kday.kday_after/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Kday.html#kday_after/2-returns"},{"type":"function","title":"Examples - Kday.kday_after/2","doc":"iex> Kday.kday_after(~D[2016-02-29], 2)\n    ~D[2016-03-01]\n\n    iex> Kday.kday_after(~D[2017-11-30], 1)\n    ~D[2017-12-04]\n\n    iex> Kday.kday_after(~D[2017-06-30], 6)\n    ~D[2017-07-01]\n\n    iex> Kday.kday_after(~D[2021-03-28], 7)\n    ~D[2021-04-04]","ref":"Kday.html#kday_after/2-examples"},{"type":"function","title":"Kday.kday_before/2","doc":"Return the date of the `day_of_week` before the\nspecified `date`.","ref":"Kday.html#kday_before/2"},{"type":"function","title":"Arguments - Kday.kday_before/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#kday_before/2-arguments"},{"type":"function","title":"Returns - Kday.kday_before/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Kday.html#kday_before/2-returns"},{"type":"function","title":"Examples - Kday.kday_before/2","doc":"iex> Kday.kday_before(~D[2016-02-29], 2)\n    ~D[2016-02-23]\n\n    iex> Kday.kday_before(~D[2017-11-30], 1)\n    ~D[2017-11-27]\n\n    # 6 means Saturday.  Use either the integer value or the atom form.\n    iex> Kday.kday_before(~D[2017-06-30], 6)\n    ~D[2017-06-24]","ref":"Kday.html#kday_before/2-examples"},{"type":"function","title":"Kday.kday_nearest/2","doc":"Return the date of the `day_of_week` nearest the\nspecified `date`.","ref":"Kday.html#kday_nearest/2"},{"type":"function","title":"Arguments - Kday.kday_nearest/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#kday_nearest/2-arguments"},{"type":"function","title":"Returns - Kday.kday_nearest/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Kday.html#kday_nearest/2-returns"},{"type":"function","title":"Examples - Kday.kday_nearest/2","doc":"iex> Kday.kday_nearest(~D[2016-02-29], 2)\n    ~D[2016-03-01]\n\n    iex> Kday.kday_nearest(~D[2017-11-30], 1)\n    ~D[2017-11-27]\n\n    iex> Kday.kday_nearest(~D[2017-06-30], 6)\n    ~D[2017-07-01]","ref":"Kday.html#kday_nearest/2-examples"},{"type":"function","title":"Kday.kday_on_or_after/2","doc":"Return the date of the `day_of_week` on or after the\nspecified `date`.","ref":"Kday.html#kday_on_or_after/2"},{"type":"function","title":"Arguments - Kday.kday_on_or_after/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#kday_on_or_after/2-arguments"},{"type":"function","title":"Returns - Kday.kday_on_or_after/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Kday.html#kday_on_or_after/2-returns"},{"type":"function","title":"Examples - Kday.kday_on_or_after/2","doc":"iex> Kday.kday_on_or_after(~D[2016-02-29], 2)\n    ~D[2016-03-01]\n\n    iex> Kday.kday_on_or_after(~D[2017-11-30], 1)\n    ~D[2017-12-04]\n\n    iex> Kday.kday_on_or_after(~D[2017-06-30], 6)\n    ~D[2017-07-01]","ref":"Kday.html#kday_on_or_after/2-examples"},{"type":"function","title":"Kday.kday_on_or_before/2","doc":"Return the date of the `day_of_week` on or before the\nspecified `date`.","ref":"Kday.html#kday_on_or_before/2"},{"type":"function","title":"Arguments - Kday.kday_on_or_before/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#kday_on_or_before/2-arguments"},{"type":"function","title":"Returns - Kday.kday_on_or_before/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Kday.html#kday_on_or_before/2-returns"},{"type":"function","title":"Examples - Kday.kday_on_or_before/2","doc":"iex> Kday.kday_on_or_before(~D[2016-02-29], 2)\n    ~D[2016-02-23]\n\n    iex> Kday.kday_on_or_before(~D[2017-11-30], 1)\n    ~D[2017-11-27]\n\n    iex> Kday.kday_on_or_before(~D[2017-06-30], 6)\n    ~D[2017-06-24]\n\n    iex> Kday.kday_on_or_before(~D[2023-09-29], 5)\n    ~D[2023-09-29]","ref":"Kday.html#kday_on_or_before/2-examples"},{"type":"function","title":"Kday.last_kday/2","doc":"Return the date of the last `day_of_week` on or before the\nspecified `date`.","ref":"Kday.html#last_kday/2"},{"type":"function","title":"Arguments - Kday.last_kday/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#last_kday/2-arguments"},{"type":"function","title":"Returns - Kday.last_kday/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument.","ref":"Kday.html#last_kday/2-returns"},{"type":"function","title":"Example - Kday.last_kday/2","doc":"# Memorial Day in the US\n    iex> Kday.last_kday(~D[2017-05-31], 1)\n    ~D[2017-05-29]","ref":"Kday.html#last_kday/2-example"},{"type":"function","title":"Kday.nth_kday/3","doc":"Return the date of the `nth` `day_of_week` on or before/after the\nspecified `date`.","ref":"Kday.html#nth_kday/3"},{"type":"function","title":"Arguments - Kday.nth_kday/3","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  Gregorian days since epoch.\n\n* `n` is the cardinal number of `k` before (negative `n`) or after\n  (positive `n`) the specified date\n\n* `k` is an integer day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Kday.html#nth_kday/3-arguments"},{"type":"function","title":"Returns - Kday.nth_kday/3","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Kday.html#nth_kday/3-returns"},{"type":"function","title":"Examples - Kday.nth_kday/3","doc":"# Thanksgiving in the US\n    iex> Kday.nth_kday(~D[2017-11-01], 4, 4)\n    ~D[2017-11-23]\n\n    # Labor day in the US\n    iex> Kday.nth_kday(~D[2017-09-01], 1, 1)\n    ~D[2017-09-04]\n\n    # Daylight savings time starts in the US\n    iex> Kday.nth_kday(~D[2017-03-01], 2, 7)\n    ~D[2017-03-12]","ref":"Kday.html#nth_kday/3-examples"},{"type":"function","title":"Kday.weeks_to_days/1","doc":"Returns the number of days in `n` weeks.","ref":"Kday.html#weeks_to_days/1"},{"type":"function","title":"Example - Kday.weeks_to_days/1","doc":"iex> Kday.weeks_to_days(2)\n    14","ref":"Kday.html#weeks_to_days/1-example"},{"type":"extras","title":"Kday","doc":"# Kday\n![Build status](https://github.com/kipcole9/kday/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/kday.svg)](https://hex.pm/packages/kday)\n[![Hex.pm](https://img.shields.io/hexpm/dw/kday.svg?)](https://hex.pm/packages/kday)\n[![Hex.pm](https://img.shields.io/hexpm/dt/kday.svg?)](https://hex.pm/packages/kday)\n[![Hex.pm](https://img.shields.io/hexpm/l/kday.svg)](https://hex.pm/packages/kday)","ref":"readme.html"},{"type":"extras","title":"Introduction - Kday","doc":"`kday` provides functions to return the date of the first, last or nth day of the week on, nearest, before or after a given date.","ref":"readme.html#introduction"},{"type":"extras","title":"Kday Installation - Kday","doc":"Add `kday` to your `deps` in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:kday, \"~> 1.0\"}\n    ...\n  ]\nend\n```","ref":"readme.html#kday-installation"},{"type":"extras","title":"Functions - Kday","doc":"* [first_kday(date, k)](https://hexdocs.pm/kday/Kday.html#first_kday/2) - Return the date of the first `day_of_week` on or after the specified `date`.\n\n* [kday_after(date, k)](https://hexdocs.pm/kday/Kday.html#kday_after/2) - Return the date of the `day_of_week` after the specified `date`.\n\n* [kday_before(date, k)](https://hexdocs.pm/kday/Kday.html#kday_before/2) - Return the date of the `day_of_week` before the specified `date`.\n\n* [kday_nearest(date, k)](https://hexdocs.pm/kday/Kday.html#kday_nearest/2) - Return the date of the `day_of_week` nearest the specified `date`.\n\n* [kday_on_or_after(date, k)](https://hexdocs.pm/kday/Kday.html#kday_on_or_after/2) - Return the date of the `day_of_week` on or after the specified `date`.\n\n* [kday_on_or_before(date, k)](https://hexdocs.pm/kday/Kday.html#kday_on_or_before/2) - Return the date of the `day_of_week` on or before the specified `date`.\n\n* [last_kday(date, k)](https://hexdocs.pm/kday/Kday.html#last_kday/2) - Return the date of the last `day_of_week` on or before the specified `date`.\n\n* [nth_kday(date, n, k)](https://hexdocs.pm/kday/Kday.html#nth_kday/3) - Return the date of the `nth` `day_of_week` on or before/after the specified `date`.","ref":"readme.html#functions"},{"type":"extras","title":"Examples - Kday","doc":"Days of the week follow the elixir convention of `1` being Monday and `7` being Sunday.\n\n```elixir\n# Memorial Day in the US\niex> Kday.last_kday(~D[2017-05-31], 1)\n~D[2017-05-29]\n\niex> Kday.kday_nearest(~D[2016-02-29], 2)\n~D[2016-03-01]\n\niex> Kday.kday_on_or_after(~D[2017-11-30], 1)\n~D[2017-12-04]\n```","ref":"readme.html#examples"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2021-2023 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Kday v1.0.2 - Changelog","doc":"This is the changelog for Kday v1.0.2 released on September 1st, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/kday/tags)\n\n#","ref":"changelog.html#kday-v1-0-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Kday.iso_days_to_day_of_week/1`. Thanks to @puruzio for the report. Closes #2,","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Kday v1.0.1 - Changelog","doc":"This is the changelog for Kday v1.0.1 released on January 31st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/kday/tags)\n\n#","ref":"changelog.html#kday-v1-0-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes `nth_kday/3` when the provided `kday` is the same day of the week as the day of the provided `date`. Thanks to @gworkman for the report and the PR.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Kday v1.0.0 - Changelog","doc":"This is the changelog for Kday v1.0.0 released on October 31st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/kipcole9/kday/tags)\n\n#","ref":"changelog.html#kday-v1-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release extracted from [ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars).","ref":"changelog.html#enhancements"}],"content_type":"text/markdown"}